Sums

Struct Sums 

pub struct Sums {
    pub cumulative_monotonic_mode: CumulativeMonotonicMode,
    pub initial_cumulative_monotonic_value: InitialCumulativeMonotonicValue,
}
OTLP sum translation settings.

Fields

cumulative_monotonic_mode: CumulativeMonotonicMode

Cumulative monotonic sum reporting mode.

Defaults to to_delta, which converts cumulative values to delta counts. Set to raw_value to emit cumulative values as gauges.

initial_cumulative_monotonic_value: InitialCumulativeMonotonicValue

Initial cumulative monotonic sum reporting behavior.

Defaults to auto, which reports the value only when its series started after the translator process. Set this to drop to always discard the first value or keep to always report it.