pub enum InitialCumulativeMonotonicValue {
Auto,
Drop,
Keep,
}Expand description
Controls how the first value of a cumulative monotonic sum is reported.
Variants
Auto
Reports the first value when its series started after the translator process.
Drop
Always drops the first value.
Keep
Always reports the first value.