Metrics

Struct Metrics 

pub struct Metrics {
    pub histogram_mode: HistogramMode,
    pub send_histogram_aggregations: bool,
    pub resource_attributes_as_tags: bool,
    pub sums: Sums,
    pub tags: String,
    pub summaries: Summaries,
}
OTLP metrics translation settings.

Fields

histogram_mode: HistogramMode

How explicit histogram buckets are reported.

send_histogram_aggregations: bool

Whether histogram count, sum, minimum, and maximum metrics are emitted when available.

The nobuckets mode requires this setting. Defaults to false.

resource_attributes_as_tags: bool

Whether every resource attribute is added as a raw metric tag, in addition to the semantic-convention mappings that are always applied.

sums: Sums

OTLP sum translation settings.

tags: String

Comma-separated list of tags to add to every emitted metric.

summaries: Summaries

OTLP summary translation settings.