pub struct Metrics {
pub histogram_mode: HistogramMode,
pub send_histogram_aggregations: bool,
pub resource_attributes_as_tags: bool,
pub sums: Sums,
pub tags: String,
pub summaries: Summaries,
}Expand description
OTLP metrics translation settings.
Fields
histogram_mode: HistogramModeHow explicit histogram buckets are reported.
send_histogram_aggregations: boolWhether histogram count, sum, minimum, and maximum metrics are emitted when available.
The nobuckets mode requires this setting. Defaults to false.
Whether every resource attribute is added as a raw metric tag, in addition to the semantic-convention mappings that are always applied.
sums: SumsOTLP sum translation settings.
Comma-separated list of tags to add to every emitted metric.
summaries: SummariesOTLP summary translation settings.